@@ -1,11 +1,12 @@
 from .constants import OffsetType
 from .consumer import Consumer
-from .producer import Producer
+from .producer import Message, Producer
 
 __version__ = '0.1.0'
 
 __all__ = [
     'Consumer',
+    'Message',
     'Producer',
     'OffsetType',
 ]
